@@ -11,8 +11,6 @@ from pathlib import Path
 CWD = Path.cwd()
 logger = logging.getLogger(__name__)
 
-projectname = 'test'
-
 
 def initialise(projectname: str) -> None:
     PROJDIR = CWD.absolute() / projectname
@@ -20,9 +18,8 @@ def initialise(projectname: str) -> None:
     os.chdir(PROJDIR)
     # Install with pipenv
     os.system('pipenv install -d')
-    VIRTUAL_ENV = os.system('pipenv --venv')
 
-    vscode_settings = {"python.pythonPath": VIRTUAL_ENV, "python.formatting.provider": "yapf"}
+    vscode_settings = {"python.formatting.provider": "yapf", "python.linting.flake8Enabled": True}
 
     VSDIR = PROJDIR / '.vscode'
     VSDIR.mkdir(exist_ok=True, parents=True)
